@@ -426,7 +426,7 @@ class CuemiacTreeView (gtk.TreeView):
 		self.connect ("cursor-changed", self.__on_cursor_changed)
 		self.set_property ("headers-visible", False)
 		self.connect ("row-activated", lambda w,p,c: self.__on_activated())
-		self.connect ("button-press-event", lambda w,e: self.__on_activated(self.get_path_at_pos(int(e.x), int(e.y))[0]))
+		self.connect ("button-press-event", self.__on_button_press_event)
 		
 		self.connect ("key-press-event", self.__on_key_press)
 				
@@ -567,7 +567,11 @@ class CuemiacTreeView (gtk.TreeView):
 		match = model[iter][model.MATCHES]
 		self.emit ("match-selected", match)
 		
-		
+	def __on_button_press_event(self, widget, event):
+		path = self.get_path_at_pos(int(event.x), int(event.y))
+		if path != None:
+			self.__on_activated(path[0])
+
 	def __on_key_press (self, widget, event):
 		# FIXME: In the future we should check for ctrl being pressed to create shortcuts
 		model, iter = self.get_selection().get_selected()
@@ -767,10 +771,8 @@ class CuemiacUI (DeskbarUI):
 		if self.invalid :
 			self.invalid = False
 			self.model.clear()
-			
-		entry_text = self.entry.get_text().strip()
-		for text, match in matches:
-			self.model.append ((text, match))
+		
+		self.model.append (matches)
 		self.popup.show_all ()
 		
 	def middle_click(self):
